@@ -601,8 +601,8 @@ __do_sjlj_init (void)
    this would be the 'length' field in a real FDE.  */
 #if defined (USE_EH_FRAME_REGISTRY) \
 	     && !__USING_SJLJ_EXCEPTIONS__
-static int __EH_FRAME_END__[]
-     __attribute__ ((unused, mode(SI), section(EH_FRAME_SECTION_NAME),
+static int __FRAME_END__[]
+     __attribute__ ((unused, section(EH_FRAME_SECTION_NAME),
 		     aligned(4)))
      = { 0 };
 static void __reg_frame_ctor (void) __attribute__ ((constructor));
